{% extends 'admin/base_admin.html' %}

{% block admin_content %}
		    <div class="container-xl">			    
			    <h1 class="app-page-title">Settings</h1>
			    <hr class="mb-4">
                <div class="row g-4 settings-section">
	                <div class="col-12 col-md-8">
		                <div class="app-card app-card-settings shadow-sm p-4">
						    
						    <div class="app-card-body">
							    <form class="settings-form" method="post">
									<input type="text" value="{{csrf}}" name="csrfmiddleware" hidden>
									{% for f in form.html() %}

								    <div class="mb-3">
									    <label for="setting-input-1" class="form-label">{{f.name|title}}</label>
										{{f.html(class='form-control')|safe}}
									</div>

									{% endfor %}								
									<button type="submit" class="btn app-btn-primary" >Save</button>
							    </form>
						    </div><!--//app-card-body-->
						    
						</div><!--//app-card-->
	                </div>
                </div><!--//row-->
                <hr class="my-4">
		    </div><!--//container-fluid-->
{% endblock admin_content %}
